##########################################################################################
## Aula 1 - Análise de dados longitudinais ###############################################
##########################################################################################
## Pacote onde esta os dados
require(HSAUR)

## Carregando a base
data(BtheB)

## Mostrando algumas obsevações
head(BtheB)

## Colocar uma coluna identificando os individuos
BtheB$subjects <- factor(rownames(BtheB))

## Calculando o numero de observações
nobs <- nrow(BtheB)

## Colocando o conjunto de dados no formato longo
BtheB_long <- reshape(BtheB, idvar = "subject", varying = c("bdi.2m","bdi.4m","bdi.6m","bdi.8m"), direction="long")

## Colocando uma coluna indexando o tempo
BtheB_long$time <- rep(c(2,4,6,8),rep(nobs,4))
head(BtheB_long)

## Carregando a lattice
require(lattice)

## verificando relação com covariáveis bdi.pre
xyplot(bdi ~ bdi.pre,data=BtheB_long)

## Usa medicamento
bwplot(bdi ~ drug,data=BtheB_long)

## length
bwplot(bdi ~ length, data=BtheB_long)

## Tratamento
bwplot(bdi ~ treatment, data=BtheB_long)

## Boxplot por tratamento
bwplot(bdi ~ as.factor(time) | treatment, data=BtheB_long)

## Trajetórias de cada ua
xyplot(bdi ~ time, groups=subject , data= BtheB_long,type="l")

##########################################################################################
### Ajustando um modelo tradicional como se fosse iid ####################################
##########################################################################################
mod.teste <- lm(bdi ~ bdi.pre + as.factor(drug) + as.factor(length) + as.factor(treatment) + time, data=BtheB_long)
summary(mod.teste)
par(mfrow=c(2,2))
plot(mod.teste)

## Ajustando um modelo de efeitos mistos
require("lme4")

## Modelo 1
mod1 <- lmer(bdi ~ bdi.pre + time + treatment + drug + length + (1 | subject), data=BtheB_long,na.action=na.omit)
summary(mod1)


## Modelo 2
mod2 <- lmer(bdi ~ bdi.pre + time + treatment + drug + length + (time | subject), data=BtheB_long,na.action=na.omit)
summary(mod2)

## Análise de resíduos
qint <- ranef(mod1)$subject[["(Intercept)"]]
qres <- residuals(mod1)

## Plotando
par(mfrow=c(1,2))
qqnorm(qint, ylab="Intercepto", xlim=c(-3,3),ylim=c(-20,20),main="Random intercept")
qqline(qint)

qqnorm(qres, ylab="Residuals", xlim=c(-3,3),ylim=c(-20,20),main="Residuals")
qqline(qres)

## Comparando os modelos
data.frame("lm" = logLik(mod.teste), "mod1" = logLik(mod1), "mod2" = logLik(mod2))
